//Set working directory if necessary
//cd "..."


///////////////////////////
//Descriptives statistics
///////////////////////////

//Load voting data
use "./Datasets/voting_data.dta", clear

//Report amount of legislation dealt with by the Council - mentioned in the Online appendix
encode InterinstitutionalCode, gen(legislative_act)
tab legislative_act
egen legislative_act_id = group(legislative_act)
tab legislative_act_id

//Report number of Council sessions covered - mentioned in the Online appendix
egen no_sessions = group(no_council_meeting)
tab no_sessions

//Recode data for information in different tables
gen opposition_vote = .
replace opposition_vote = 0 if Vote == "Yes"
replace opposition_vote = 1 if Vote == "No"
replace opposition_vote = 1 if Vote == "Abstain"
label variable opposition_vote "Binary indicator of opposition vote by government"

gen no_vote = .
replace no_vote = 0 if Vote == "Yes"
replace no_vote = 1 if Vote == "No"
replace no_vote = 0 if Vote == "Abstain"
label variable no_vote "Binary indicator of no vote by government"

//Collapse data
collapse (max) opposition_vote no_vote (firstnm) Package Vote Inter no_council_meeting no_debate no_suffix, by(legislative_act actor)
collapse (sum) opposition_vote no_vote (firstnm) Package Vote Inter no_council_meeting no_debate no_suffix, by(legislative_act)

//Produce TABLE A2 in the Online appendix 
estpost tab opposition_vote if Vote != "MISSING" & Vote != "NON-LEGISLATIVE" & Vote != "NOT DECIDED" & Vote != "WITHDRAWAL"
esttab using "./Tables/Table_A2.rtf", replace cells("b(label(freq)) pct(fmt(2)) cumpct(fmt(2))") varlabels(`e(labels)') nonumber nomtitle noobs label 

estpost tab no_vote if Vote != "MISSING" & Vote != "NON-LEGISLATIVE" & Vote != "NOT DECIDED" & Vote != "WITHDRAWAL"
esttab using "./Tables/Table_A2.rtf", append cells("b(label(freq)) pct(fmt(2)) cumpct(fmt(2))") varlabels(`e(labels)') nonumber nomtitle noobs label 

//Status of acts as of 15th June 2018 - mentioned in the Online appendix
gen status = Vote
replace status = "PASSED" if Vote == "Abstain"
replace status = "PASSED" if Vote == "No"
replace status = "PASSED" if Vote == "Yes"
replace status = "PASSED" if Vote == "MISSING"
replace status = "PASSED" if Vote == "NON-LEGISLATIVE"
tab status
label variable status "Status of acts as of 15th of June 2018"

//Produce TABLE A3 in the Online appendix
estpost tab Package
esttab using "./Tables/Table_A3.rtf", replace cells("b(label(freq)) pct(fmt(2)) cumpct(fmt(2))") varlabels(`e(labels)') nonumber nomtitle noobs label 

//Produce TABLE A1 in the Online appendix
gen procedure = substr(Inter,-3,.)
replace procedure = "BUDGET" if procedure != "COD" & procedure != "APP" & procedure != "CNS" & procedure != "NLE"
estpost tab procedure
esttab using "./Tables/Table_A1.rtf", replace cells("b(label(freq)) pct(fmt(2)) cumpct(fmt(2))") varlabels(`e(labels)') nonumber nomtitle noobs label 

//Integrate information from Eur-Lex
use "./Datasets/voting_data.dta", clear
collapse no_debate, by(no_council_meeting InterinstitutionalCode)
keep if substr(InterinstitutionalCode,1,2) == "20"
merge m:1 InterinstitutionalCode no_council_meeting using "./Datasets/eurlex.dta"
//31 debates not matched from master, not on Eur-Lex - mentioned in the Online appendix

//Display acts where dataset does not cover whole lifetime
gen in_period = 0
replace in_period = 1 if _merge == 1
replace in_period = 1 if date(EventDate, "DMY") >= date("01/01/2010", "DMY") & date(EventDate, "DMY") <= date("31/12/2015", "DMY")
tab InterinstitutionalCode if in_period == 0
//41 debates not matched from using minus 4 where lifetime is not fully covered is 37, on Eur-Lex but not in DICEU - mentioned in the Online appendix

//Integrate meta information on debates
use "./Datasets/diceu_meta_information_interventions.dta", clear
collapse (firstnm) Package, by(no_council_meeting no_debate no_suffix)
merge 1:m no_council_meeting no_debate no_suffix using "./Datasets/voting_data.dta", replace update
drop _merge
collapse (firstnm) VotingRule, by(no_council_meeting no_debate no_suffix Package)

//Produce TABLE A4 in the Online appendix
estpost tab Package
esttab using "./Tables/Table_A4.rtf", replace cells("b(label(freq)) pct(fmt(2)) cumpct(fmt(2))") varlabels(`e(labels)') nonumber nomtitle noobs label 

//Load participation data
use "./Datasets/diceu_meta_information_interventions.dta", clear

//Frequency of national ministers giving speeches - mentioned in footnote 4 in the article
tab speaker_position if speaker_position <= 3

//Produce TABLE A5 in the Online appendix
estpost tab actor 
esttab using "./Tables/Table_A5.rtf", replace cells("b(label(freq)) pct(fmt(2)) cumpct(fmt(2))") varlabels(`e(labels)') nonumber nomtitle noobs label 

//Load approval data
use "./Datasets/diceu_approval_debates_wide.dta", clear

//Produce TABLE A7 in the Online appendix
egen mean_approval = rowmean(approval*)
label variable mean_approval "Average general approval by actor"
estpost tabstat mean_approval, by(actor)
esttab using "./Tables/Table_A7.rtf", replace cells("mean(fmt(2))") label

//Number of debates not codebook compatible - mentioned in Online appendix
import excel "./Datasets/DICEU_human_codings_ECOFIN.xlsx", sheet("Debates coding") firstrow clear
tab Codebookcom

//Mean length of debates - mentioned in the article
sum V1_MINUTES if Codebookc == "Yes"

