rm(list = ls())  # clear

#Set working directory if necessary
#setwd("...")

#Install version 0.9.9-50 of "quanteda" package: note that other versions may not work
require(devtools)
install_version("quanteda", version = "0.9.9-50", repos = "http://cran.us.r-project.org")

#Load packages - please install the indicated versions if not already installed
require(tm) #0.7-3
require(quanteda) #0.9.9-50
require(stringr) #1.3.1
require(readstata13) #0.9.2
require(dplyr) #0.7.4
require(plyr) #1.8.4
require(calibrate) #1.7.2
require(MCMCpack) #1.4-1
require(KernSmooth) #2.23-15
require(lattice) #0.20-35
require(latticeExtra) #0.6-28
require(ggplot2) #3.1.0
require(car) #2.1-6
require(coda) #0.19-1
require(xtable) #1.8-3


#########################################
##Corpus preparation and pre-processing
#########################################

#ATTENTION! If you run this script on Windows, the corpus
#may not be fed in correctly. For this case, we provide the
#correct corpus as an .RData-file compiled on Mac OS. 
#If you are using Windows, please do not run the Mac OS code 
#below in lines 39-40 but uncomment the code for Windows in line 43

#Import DICEU speech data - for Mac OS
council <- VCorpus(DirSource("./Text corpus/"), readerControl = list(language = "eng"))
summary(council)

#Import DICEU speech data - for Windows (UNCOMMENT line 43)
#load("./Datasets/corpus.RData")

#Convert actor codes to tags (using whole words only)
council <- tm_map(council, content_transformer(function(x) gsub(" $","", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^ ","", x)))
council <- tm_map(council, content_transformer(function(x) gsub("ADDRESS WEBCAST 1:", "##METAINFO ADDRESS WEBCAST 1:", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^N/A\\b", "##NA", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^AT\\b", "##AT", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^BE\\b", "##BE", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^BG\\b", "##BG", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^CZ\\b", "##CZ", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^CY\\b", "##CY", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^DE\\b", "##DE", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^DK\\b", "##DK", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^EE\\b", "##EE", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^EL\\b", "##EL", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^ES\\b", "##ES", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^FI\\b", "##FI", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^FR\\b", "##FR", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^HR\\b", "##HR", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^HU\\b", "##HU", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^IE\\b", "##IE", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^IT\\b", "##IT", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^LT\\b", "##LT", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^LU\\b", "##LU", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^LV\\b", "##LV", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^MT\\b", "##MT", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^NL\\b", "##NL", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^PL\\b", "##PL", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^PT\\b", "##PT", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^RO\\b", "##RO", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^SE\\b", "##SE", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^SI\\b", "##SI", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^SK\\b", "##SK", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^UK\\b", "##UK", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^COM\\b", "##COM", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^OTH\\b", "##OTH", x)))
council <- tm_map(council, content_transformer(function(x) gsub("^N/A\\b", "##N/A", x)))

#Load corpus into quanteda
council <- corpus(council)
numbers <- names(council[1:ndoc(council)])
docvars(council, "number") <- as.integer(substring(numbers, 5, 7))

#Use loop to segment documents by intervention
text <- corpus_subset(council, number == 1)
segmented_text <- corpus_segment(text, "tags")
council_aux <- segmented_text

for(doc in 2:ndoc(council))
{
  text <- corpus_subset(council, number == doc)
  segmented_text <- corpus_segment(text, "tags")
  council_aux <- council_aux + segmented_text
}

council <- council_aux

#Add document-level identifiers
meetings <- docvars(council, "id")
docvars(council, "no_council_meeting") <- as.integer(substring(meetings, 1, 4))
docvars(council, "no_debate") <- as.integer(str_sub(meetings, -5, -5)) 
docvars(council, "no_suffix") <- gsub("_", "", substring(meetings, 5, 5))
docvars(council, "actor") <- gsub("##", "", docvars(council, "tag"))

#Load intervention variables from STATA
meta_texts <- docvars(council)
meta_texts$row <- 1:nrow(meta_texts)
meta_interventions <- read.dta13("./Datasets/diceu_meta_information_interventions.dta")
meta_interventions$SAMPLE <- 1

#Merge intervention variables from STATA and corpus meta information, and sort
council_meta <- merge(meta_texts, meta_interventions, by = c("no_council_meeting", "no_debate", "actor", "no_suffix"), all.x = TRUE)
council_meta <- arrange(council_meta, row)

#Add merged meta information to corpus
docvars(council) <- council_meta

#Get rid of METAINFO observations and data from DICEU-DEU comparison
council_eco <- corpus_subset(council, tag != "##METAINFO" & SAMPLE == 1)
  

######################################
##Estimate wordfish/wordshoal models
######################################

#Create a document feature matrix (dfm) with pooled interventions as units
dfm.council_eco_interventions <- dfm(council_eco, tolower = TRUE, groups = c("id", "actor"), stem = FALSE, remove_punct = TRUE)
dfm.council_eco_interventions <- dfm_trim(dfm.council_eco_interventions)

#Get actor * id table for wordshoal
wordshoal_params <- unique(docvars(council_eco, c("id", "actor")))
wordshoal_params <- wordshoal_params[order(wordshoal_params$actor),]

#Estimate wordshoal model for debates and actors
#Note that due to internal procedures of quanteda, the estimates can slightly vary after each run (from the third digit after the comma)
#Regrettably, this cannot be fixed with setting random seeds
wordshoal_council_eco <- textmodel_wordshoal(dfm.council_eco_interventions, dir=c(4, 30), groups = wordshoal_params$id, authors = wordshoal_params$actor)
summary(wordshoal_council_eco)

#Create a document feature matrix (dfm) with actors as units
dfm.council_eco_actors <- dfm(council_eco, tolower = TRUE, groups = c("actor"), stem = FALSE, remove_punct = TRUE)
dfm.council_eco_actors <- dfm_trim(dfm.council_eco_actors)

#Estimate wordfish models
wordfish_council_eco <- textmodel_wordfish(dfm.council_eco_actors, dir=c(4, 30))
summary(wordfish_council_eco)

#Plot FIGURE A2 in the Online appendix
dpi=300    #pixels per square inch
png("./Figures/Figure_A2.png", width=6*dpi, height=9*dpi, res=dpi)
textplot_scale1d(wordfish_council_eco, margin = "features", highlighted = c("tax", "macroeconomic", "bailout", "eurozone", "mario", "jean-claude", "japan", "hong", "tax-payers","irresponsibility","bankers", "crisis", "tax-deductible", "transformation", "credit", "risk", "non-taxation", "shock", "bailing-in", "reimbursing", "recapitalized", "bailed-in"))
dev.off()


#######################################
##Calculate descriptives about corpus
#######################################

#Figures are partially mentioned in the article
mean(ntoken(dfm.council_eco_interventions))
median(ntoken(dfm.council_eco_interventions))
ntoken(dfm.council_eco_actors)

#Produce TABLE A6 in the Online appendix
Table_A6 <- as.matrix(ntoken(dfm.council_eco_actors))
print.xtable(xtable(Table_A6, digits = (0)), type="html", file="./Tables/Table_A6.html", caption.placement = "top", append = FALSE)
sum(ntoken(dfm.council_eco_actors))


#######################################
##Plot wordshoal estimates over time
#######################################

#Prepare data
dates <- unique(docvars(council_eco, c("intervention_date", "actor", "id")))
debate_level <- unique(docvars(council_eco, c("id", "intervention_date", "Package")))
debate_level$beta <- wordshoal_council_eco@beta
intervention_level <- as.data.frame(cbind(psi = wordshoal_council_eco@psi)) 
intervention_level$actor <- wordshoal_council_eco@authors
intervention_level$id <- wordshoal_council_eco@groups
intervention_level <- merge(intervention_level, debate_level, by = c("id"), all.x = TRUE)
intervention_level$position <- intervention_level$psi * intervention_level$beta
intervention_level$date_int <- as.numeric(intervention_level$intervention_date) 
intervention_level$government <- as.numeric(intervention_level$actor) 

#Plot FIGURE A4
png("./Figures/Figure_A4-1.png", width=6*dpi, height=9*dpi, res=dpi)
countries1 <- c("AT", "BE", "BG", "CY", "CZ", "DE", "DK", "EE", "EL")
ggplot(intervention_level[intervention_level$actor %in% countries1,] , aes(intervention_date, abs(position))) +
  geom_point() +
  geom_smooth(colour = "black", span = 0.75) +
  labs(x = "Year", y = "Debate-specific position") +
  geom_point(colour = "gray35", size = 2) +
  facet_wrap(~actor) +
  theme_bw()
dev.off()

png("./Figures/Figure_A4-2.png", width=6*dpi, height=9*dpi, res=dpi)
countries2 <- c("ES", "FI", "FR", "HU", "IE", "IT", "LT", "LU", "LV")
ggplot(intervention_level[intervention_level$actor %in% countries2,] , aes(intervention_date, abs(position))) +
  geom_point() +
  geom_smooth(colour = "black", span = 0.75) +
  labs(x = "Year", y = "Debate-specific position") +
  geom_point(colour = "gray35", size = 2) +
  facet_wrap(~actor) +
  theme_bw()
dev.off()

png("./Figures/Figure_A4-3.png", width=6*dpi, height=9*dpi, res=dpi)
countries3 <- c("MT", "NL", "PL", "PT", "RO", "SE", "SI", "SK", "UK")
ggplot(intervention_level[intervention_level$actor %in% countries2,] , aes(intervention_date, abs(position))) +
  geom_point() +
  geom_smooth(colour = "black", span = 0.75) +
  labs(x = "Year", y = "Debate-specific position") +
  geom_point(colour = "gray35", size = 2) +
  facet_wrap(~actor) +
  theme_bw()
dev.off()


#########################################
##Investigate debate loadings over time
#########################################

#Plot FIGURE 2 in the article
png("./Figures/Figure_2.png", width=5*dpi, height=5*dpi, res=dpi)
ggplot(debate_level, aes(intervention_date, abs(beta))) +
  geom_point() +
  geom_smooth(colour = "black", span = 0.75) +
  labs(x = "Year", y = "Debate loadings (absolute value)") +
  geom_point(colour = "gray35", size = 2) +
  theme_bw()
dev.off()

#Assign debates into five issue areas
debate_level <- debate_level[order(abs(debate_level$beta)),]
debate_level$issue <- ""
debate_level$issue[debate_level$Package == "Two pack"] <- "Macroeconomic coordination"
debate_level$issue[debate_level$Package == "Six pack"] <- "Macroeconomic coordination"
debate_level$issue[debate_level$Package == "European fund for strategic investments (EFSI)"] <- "Macroeconomic coordination"
debate_level$issue[debate_level$Package == "Financial assistance to non-eurozone member states"] <- "Macroeconomic coordination"

debate_level$issue[debate_level$Package == "Financial transaction tax (FTT)"] <- "Taxation"
debate_level$issue[debate_level$Package == "Common system of value added tax (VAT)"] <- "Taxation"
debate_level$issue[debate_level$Package == "Taxation of savings income"] <- "Taxation"
debate_level$issue[debate_level$Package == "Common VAT treatment of insurance and financial services"] <- "Taxation"
debate_level$issue[debate_level$Package == "Taxation of parent companies and subsidiaries"] <- "Taxation"
debate_level$issue[debate_level$Package == "Automatic exchange of information in the field of taxation"] <- "Taxation"
debate_level$issue[debate_level$Package == "Common consolidated corporate tax base"] <- "Taxation"
debate_level$issue[debate_level$Package == "Common system of taxation applicable to interest and royalty payments"] <- "Taxation"
debate_level$issue[debate_level$Package == "Administrative cooperation in taxation"] <- "Taxation"
debate_level$issue[debate_level$Package == "Energy taxation directive"] <- "Taxation"

debate_level$issue[debate_level$Package == "Revised capital requirements rules (CRD IV)"] <- "Banking union"
debate_level$issue[debate_level$Package == "Single resolution mechanism (SRM) and single resolution fund (SRF)"] <- "Banking union"
debate_level$issue[debate_level$Package == "Banking supervisory mechanism"] <- "Banking union"
debate_level$issue[debate_level$Package == "Credit institutions and investment firms: recovery and resolution"] <- "Banking union"
debate_level$issue[debate_level$Package == "Deposit guarantee schemes"] <- "Banking union"
debate_level$issue[debate_level$Package == "European deposit insurance scheme (EDIS)"] <- "Banking union"
debate_level$issue[debate_level$Package == "Structural measures improving the resilience of EU credit institutions"] <- "Banking union"

debate_level$issue[debate_level$Package == "Budget 2011"] <- "Budget"
debate_level$issue[debate_level$Package == "Budget 2012"] <- "Budget"
debate_level$issue[debate_level$Package == "Budget 2013"] <- "Budget"
debate_level$issue[debate_level$Package == "Budget 2014"] <- "Budget"
debate_level$issue[debate_level$Package == "Budget 2015"] <- "Budget"
debate_level$issue[debate_level$Package == "Budget 2016"] <- "Budget"

debate_level$issue[debate_level$issue == ""] <- "Other"

debate_level$issue <- as.factor(debate_level$issue)

#Mean of betas by issue area
aggregate(debate_level$beta, list(debate_level$issue), mean)

#Check how debate loadings develop within issue area over time - mentioned in footnote 7 in the article
myTheme <- trellis.par.get()
myTheme$superpose.symbol$pch <-1:7
xyplot(abs(beta) ~ intervention_date, debate_level, group = issue, par.settings = myTheme, grid = TRUE, type = c("p", "smooth"), lwd = 2, auto.key = list(columns = 4, cex = 0.75), xlab = "Year", ylab = "Debate marginal effects", width = 20, height = 28)


#############################
##Perform sentiment analysis
#############################

#Load Lexicoder and create document feature matrices (dfms) from dictionaries
lexicoder <- dictionary(file = "./Dictionaries/LSD2015.lc3", format = "lexicoder")
lexicoder_neg <- dictionary(file = "./Dictionaries/LSD2015_NEG.lc3", format = "lexicoder")
dfm.sentiment_council_eco <- dfm(council_eco, groups = c("actor"), dictionary = lexicoder)
dfm.sentiment_council_eco_neg <- dfm(council_eco, groups = c("actor"), dictionary = lexicoder_neg)

#Calculate tone
sentiment <- as.data.frame(dfm.sentiment_council_eco@Dimnames$docs)
colnames(sentiment) <- "actor"
sentiment$negative <- as.numeric(dfm.sentiment_council_eco[,1])
sentiment$positive <- as.numeric(dfm.sentiment_council_eco[,2])
sentiment$neg_positive <- as.numeric(dfm.sentiment_council_eco_neg[,1])
sentiment$neg_negative <- as.numeric(dfm.sentiment_council_eco_neg[,2])
sentiment$tokens <- ntoken(dfm.council_eco_actors)
sentiment$positive_tokens <- sentiment$positive - sentiment$neg_positive + sentiment$neg_negative
sentiment$negative_tokens <- sentiment$negative - sentiment$neg_negative + sentiment$neg_positive
sentiment$tone <- (sentiment$positive_tokens - sentiment$negative_tokens) / sentiment$tokens 


###########################
##Measure issue attention
###########################

#Load policy agendas dictionary and create document feature matrix (dfm) from dictionary
lexicoder_policy_agendas <- dictionary(file = "./Dictionaries/policy_agendas_english.lc3", format = "lexicoder")
dfm.topics_council_eco <- dfm(council_eco, groups = c("actor"), dictionary = lexicoder_policy_agendas)

#Calculate salience
salience = data.frame("actor" = dfm.topics_council_eco@Dimnames$docs)
salience$macroeconomics <- dfm.topics_council_eco[,colnames(dfm.topics_council_eco)=="+macroeconomics"]
salience$finance <- dfm.topics_council_eco[,colnames(dfm.topics_council_eco)=="+finance"]
salience$trade <- dfm.topics_council_eco[,colnames(dfm.topics_council_eco)=="+foreign_trade"]
salience$total <- rowSums(dfm.topics_council_eco)
salience$perc_macroeconomics <- salience$macroeconomics/salience$total
salience$perc_finance <- salience$finance/salience$total
salience$perc_trade <- salience$trade/salience$total

salience <- salience[order((-1)*salience$perc_macroeconomics),]
keywords <- t(as.matrix(salience[,6:8]))

#Plot FIGURE A3 in the Online appendix
dpi=300    #pixels per square inch
png("./Figures/Figure_A3.png", width=7*dpi, height=5*dpi, res=dpi)
par(mar=c(7,3,1,1))
barplot(keywords, names.arg= salience$actor, las = 2, legend = c("Macroeconomics", "Banking & Finance", "International trade"), args.legend = list(x = "bottom", ncol = 3,  bty = "n", inset=c(0, -0.3)))
dev.off()


##########################################
##Estimate IRT model from human codings
##########################################

#Load approval data - note that only 88 debates, since in one debate approval of all speakers could not be assessed (='9')
council_approval <- read.dta13("./Datasets/diceu_approval_debates_wide.dta")

#Subset to debates with at least two different positions taken by governments
valid_item <- rapply(council_approval,function(x)length(unique(x)))
valid_item[valid_item == 1] <- 0
valid_item[valid_item > 2] <- 1
council_approval_subset <- council_approval[,valid_item == 1]

#Estimate IRT approval with MCMCpack package
#Please note that Windows users may obtain slightly different results
#due to differences in the random number generation between 
#Mac OS and Windows
matrix <- as.matrix(council_approval_subset)
irt_approval <- MCMCordfactanal(matrix, factors = 1, lambda.constraints=list(Drawing=list(2,"+")), data = council_approval_subset, burnin=500000, mcmc=1000000, thin=100, l0 = 0, L0 = 0.1, store.lambda = TRUE, store.scores = TRUE, seed = 123456, tune = 5.5)

#Extract ideal points
means.sds <- summary(irt_approval)[[1]][,1:4]
ideal.points_irt_approval <- means.sds[grepl("phi", rownames(means.sds)),]
cis.points_irt_approval <- HPDinterval(irt_approval)
cis.points_irt_approval <- cis.points_irt_approval[grepl("phi", rownames(cis.points_irt_approval)),]

#Sort according to factor loadings, investigate discrimination parameters - was used to construct Table A8 in the Online Appendix
item.params_irt_approval <- means.sds[grepl("Lambda", rownames(means.sds)),]
item.params_irt_approval <- item.params_irt_approval[order(abs(item.params_irt_approval[,1])),]

#Summarise results and diagnose convergence
summary(irt_approval)
geweke.diag(irt_approval)
geweke <- unlist(geweke.diag(irt_approval))

#Plot FIGURE A1 in the Online appendix
png("./Figures/Figure_A1.png", width=7*dpi, height=6*dpi, res=dpi)
hist(geweke[1:312], main ="", xlab="")
dev.off()

#Show how many Geweke statistics are smaller than -2 or greater than +2 - mentioned in the Online appendix
geweke <- geweke[geweke < -2 | geweke > 2]


########################
##Compare ideal points
########################

#Join all ideal point estimates
ideal_points <- data.frame(actor = council_approval$actor)
ideal_points$irt_approval_thetas <- ideal.points_irt_approval[,1]
ideal_points$irt_approval_lb <- cis.points_irt_approval[,1] 
ideal_points$irt_approval_ub <- cis.points_irt_approval[,2] 
ideal_points$wordfish_thetas <- wordfish_council_eco@theta
ideal_points$wordfish_lb <- wordfish_council_eco@theta - 1.96 * wordfish_council_eco@se.theta
ideal_points$wordfish_ub <- wordfish_council_eco@theta + 1.96 * wordfish_council_eco@se.theta
ideal_points$wordshoal_thetas <- wordshoal_council_eco@theta
ideal_points$wordshoal_lb <- wordshoal_council_eco@theta - 1.96 * wordshoal_council_eco@se.theta
ideal_points$wordshoal_ub <- wordshoal_council_eco@theta + 1.96 * wordshoal_council_eco@se.theta
sentiment <- sentiment[order(sentiment$actor),]
ideal_points$tone <- sentiment$tone

#Exclude COM & OTH
ideal_points <- ideal_points[c(-4,-23),]

#Produce TABLE 1 in the article
Table_1 <- cor(ideal_points[,c(2, 5, 8, 11)])
print.xtable(xtable(Table_1, digits=c(2, 2, 2, 2, 2)), type="html", file="./Tables/Table_1.html", caption.placement = "top", append = FALSE)

#Plot FIGURE 1 in the article
png("./Figures/Figure_1.png", width=8*dpi, height=10*dpi, res=dpi)

par(mfrow=c(2,2), mar = c(5,5,5,2))

ideal_points <- ideal_points[order(ideal_points$irt_approval_thetas),]
plot(0, 0, type="n", xlim=c(-1.8, 1.5),ylim=c(0,nrow(ideal_points)+1), xlab="Estimated position", ylab="", main=paste("(a) Ideal points from IRT approval"), axes=FALSE)
axis(1)
for (v in -2:3) abline(v= v*0.5, col="light grey")
points(ideal_points$irt_approval_thetas, 1:nrow(ideal_points), pch=16, cex=0.8)
for (i in 1:nrow(ideal_points)){
  lines(c(ideal_points$irt_approval_lb[i], ideal_points$irt_approval_ub[i]), rep(i,2), lwd=1.5)	
  text(ideal_points$irt_approval_lb[i]-0.20, i, ideal_points$actor[i], pos=2, cex=0.8)
}	

ideal_points <- ideal_points[order(ideal_points$wordfish_thetas),]
plot(0, 0, type="n", xlim=c(-2.3, 3),ylim=c(0,nrow(ideal_points)+1), xlab="Estimated position", ylab="", main=paste("(b) Ideal points from Wordfish"), axes=FALSE)
axis(1)
for (v in -3:5) abline(v= v*0.5, col="light grey")
points(ideal_points$wordfish_thetas, 1:nrow(ideal_points), pch=16, cex=0.8)
for (i in 1:nrow(ideal_points)){
  lines(c(ideal_points$wordfish_lb[i], ideal_points$wordfish_ub[i]), rep(i,2), lwd=1.5)	
  text(ideal_points$wordfish_lb[i]-0.20, i, ideal_points$actor[i], pos=2, cex=0.8)
}	

plot(ideal_points$irt_approval_thetas, ideal_points$wordfish_thetas, col = "gray35", main = "(c) IRT approval and Wordfish", xlab = "IRT approval", ylab = "Wordfish", xlim = c(-0.8, 1.5), ylim = c(-1.8, 2.5))
textxy(ideal_points$irt_approval_thetas, ideal_points$wordfish_thetas, ideal_points$actor, cex = 0.8)
abline(lm(ideal_points$wordfish_thetas ~ ideal_points$irt_approval_thetas))

plot(ideal_points$irt_approval_thetas, ideal_points$tone, col = "gray35", main = "(d) IRT approval and tone", xlab = "IRT approval", ylab = "Tone", xlim = c(-0.8, 1.5), ylim = c(0.02, 0.08))
textxy(ideal_points$irt_approval_thetas, ideal_points$tone, ideal_points$actor, cex = 0.8)
abline(lm(ideal_points$tone ~ ideal_points$irt_approval_thetas))

dev.off()


#############################################################
##Re-estimate wordfish/wordshoal models without COM and OTH
#############################################################

#Get rid of METAINFO, COM & OTH observations and data from DICEU-DEU comparison
council_eco_COMOTH <- corpus_subset(council, tag != "##METAINFO" & tag != "##COM" & tag != "##OTH" & SAMPLE == 1)

#Create a document feature matrix (dfm) with pooled interventions as units
dfm.council_eco_interventions_COMOTH <- dfm(council_eco_COMOTH, tolower = TRUE, groups = c("id", "actor"), stem = FALSE, remove_punct = TRUE)
dfm.council_eco_interventions_COMOTH <- dfm_trim(dfm.council_eco_interventions_COMOTH)

#Get actor * id table for wordshoal
wordshoal_params_COMOTH <- unique(docvars(council_eco_COMOTH, c("id", "actor")))
wordshoal_params_COMOTH <- wordshoal_params_COMOTH[order(wordshoal_params_COMOTH$actor),]

#Estimate wordshoal model for debates and actors
#Note that due to internal procedures of quanteda, the estimates can slightly vary after each run (from the third digit after the comma)
#Regrettably, this cannot be fixed with setting random seeds
wordshoal_council_eco_COMOTH <- textmodel_wordshoal(dfm.council_eco_interventions_COMOTH, dir=c(4, 28), groups = wordshoal_params_COMOTH$id, authors = wordshoal_params_COMOTH$actor)
summary(wordshoal_council_eco_COMOTH)

#Create a document feature matrix (dfm) with actors as units
dfm.council_eco_actors_COMOTH <- dfm(council_eco_COMOTH, tolower = TRUE, groups = c("actor"), stem = FALSE, remove_punct = TRUE)
dfm.council_eco_actors_COMOTH <- dfm_trim(dfm.council_eco_actors_COMOTH)

#Estimate wordfish models
wordfish_council_eco_COMOTH <- textmodel_wordfish(dfm.council_eco_actors_COMOTH, dir=c(4, 28))
summary(wordfish_council_eco_COMOTH)

#IRT model from human coding
#Subset to debates with at least two different positions taken by governments
valid_item <- rapply(council_approval[council_approval$actor != "OTH" & council_approval$actor != "COM",],function(x)length(unique(x)))
valid_item[valid_item == 1] <- 0
valid_item[valid_item > 2] <- 1
council_approval_subset_COMOTH <- council_approval[council_approval$actor != "OTH" & council_approval$actor != "COM",valid_item == 1]

#Estimate IRT approval with MCMCpack package
matrix_COMOTH <- as.matrix(council_approval_subset_COMOTH)
irt_approval_COMOTH <- MCMCordfactanal(matrix_COMOTH, factors = 1, lambda.constraints=list(Drawing=list(2,"+")), data = council_approval_subset[council_approval_subset$actor != "OTH" & council_approval_subset$actor != "COM",], burnin=500000, mcmc=1000000, thin=100, l0 = 0, L0 = 0.1, store.lambda = TRUE, store.scores = TRUE, seed = 123456, tune = 5.5)

#Extract ideal points
means.sds_COMOTH <- summary(irt_approval_COMOTH)[[1]][,1:4]
ideal.points_irt_approval_COMOTH <- means.sds_COMOTH[grepl("phi", rownames(means.sds_COMOTH)),]
cis.points_irt_approval_COMOTH <- HPDinterval(irt_approval_COMOTH)
cis.points_irt_approval_COMOTH <- cis.points_irt_approval_COMOTH[grepl("phi", rownames(cis.points_irt_approval_COMOTH)),]

#Join new ideal points
ideal_points <- ideal_points[order(ideal_points$actor),]
ideal_points$irt_approval_thetas_COMOTH <- ideal.points_irt_approval_COMOTH[,1]
ideal_points$irt_approval_lb_COMOTH <- cis.points_irt_approval_COMOTH[,1] 
ideal_points$irt_approval_ub_COMOTH <- cis.points_irt_approval_COMOTH[,2] 
ideal_points$wordfish_thetas_COMOTH <- wordfish_council_eco_COMOTH@theta
ideal_points$wordfish_lb_COMOTH <- wordfish_council_eco_COMOTH@theta - 1.96 * wordfish_council_eco_COMOTH@se.theta
ideal_points$wordfish_ub_COMOTH <- wordfish_council_eco_COMOTH@theta + 1.96 * wordfish_council_eco_COMOTH@se.theta
ideal_points$wordshoal_thetas_COMOTH <- wordshoal_council_eco_COMOTH@theta
ideal_points$wordshoal_lb_COMOTH <- wordshoal_council_eco_COMOTH@theta - 1.96 * wordshoal_council_eco_COMOTH@se.theta
ideal_points$wordshoal_ub_COMOTH <- wordshoal_council_eco_COMOTH@theta + 1.96 * wordshoal_council_eco_COMOTH@se.theta

#Correlate ideal points - differences to baseline estimation are minimal, discussed in footnote 6 in the article  
cor(ideal_points[,c(2, 5, 8, 11, 12, 15, 18)])


