//Set working directory if necessary
//cd "..."


//Load dataset
use "./Datasets/diceu_voting_analysis.dta", clear


////////////////////////
//Descriptive analysis
////////////////////////

//Number of opposition and no votes - mentioned in the article
tab opposition_vote
tab no_vote

//Report Goodman and Kruskal’s gamma - mentioned in the article
tab approval_first opposition_vote, row gamma chi2
tab approval_first no_vote, row gamma chi2

//Plot FIGURE 3 in the article
tab approval_first if opposition_vote != .
graph bar (mean) opposition_vote (mean) no_vote, over(approval_first, relabel(1 `" "Full approval" "n=489" "' 2 `" "More approval" "n=555" "' 3 `" "Balance" "n=211" "' 4 `" "More disapproval" "n=331" "' 5 `" "Full disapproval" "n=159" "') label(labsize(small))) blabel(total, format(%03.2f)) ytitle("Fraction of opposition/no votes") legend(order(1 "Opposition votes" 2 "No votes") cols(1) size(small) position(10) ring(0)) scheme(lean2) b1title("DICEU general approval")
graph export "./Figures/Figure_3.png", replace height(1500)

//Number of opposition votes from budget debates - mentioned in the article
tab opposition_vote if budget_debates == 1


////////////////////////////
//Main regression analyses
////////////////////////////

//Perform multiple imputation
xtset country legislative_act
mi set flong
mi register imputed approval_first approval_last image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation
set seed 12345
mi impute chained (pmm, knn(5)) approval_first approval_last image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation = opposition_vote no_vote i.country i.legislative_act, add(30) burnin(100) force

//Estimate models for TABLE 3 in the article
mi estimate, post cmdok: logit opposition_vote approval_first image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation budget
outreg using "./Tables/Table_3.doc", replace starlevels(5) sdec(2) se
mi estimate, post cmdok: logit opposition_vote approval_first image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation budget i.country
outreg using "./Tables/Table_3.doc", merge starlevels(5) sdec(2) se


///////////////////
//Online appendix
///////////////////

//Estimate Model A1 in TABLE A9 in the Online appendix
mi estimate, post cmdok: logit opposition_vote approval_last image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation budget
outreg using "./Tables/Table_A9.doc", replace starlevels(5) se

//Estimate Model A2 in TABLE A9 in the Online appendix
mi estimate, post cmdok: logit opposition_vote approval_last image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation budget i.country
outreg using "./Tables/Table_A9.doc", merge starlevels(5) se

//Estimate Model A3 in TABLE A9 in the Online appendix
mi estimate, post cmdok: logit no_vote approval_first image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation budget
outreg using "./Tables/Table_A9.doc", merge starlevels(5) se

//Estimate Model A4 in TABLE A9 in the Online appendix
mi estimate, post cmdok: logit no_vote approval_first image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation budget i.country
outreg using "./Tables/Table_A9.doc", merge starlevels(5) se

//Estimate models with no votes as DV and last approval - results mentioned in the Online appendix
mi estimate, post cmdok: logit no_vote approval_last image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation budget
mi estimate, post cmdok: logit no_vote approval_last image_lag6m gov_eu_cmp_static gov_lr_cmp_static eu_cont_gdp unemployment inflation budget i.country

